@@ -609,8 +609,8 @@ class Stream:
         try:
             # Stream Manifest is base64 encoded.
             return base64.b64decode(self.manifest).decode("utf-8")
-        except:
-            raise ManifestDecodeError
+        except Exception as e:
+            raise ManifestDecodeError from e
 
     @property
     def is_mpd(self) -> bool:
@@ -761,15 +761,15 @@ class DashInfo:
         try:
             if stream.is_mpd and not stream.is_encrypted:
                 return DashInfo(stream.get_manifest_data())
-        except:
-            raise ManifestDecodeError
+        except Exception as e:
+            raise ManifestDecodeError from e
 
     @staticmethod
     def from_mpd(mpd_manifest) -> "DashInfo":
         try:
             return DashInfo(mpd_manifest)
-        except:
-            raise ManifestDecodeError
+        except Exception as e:
+            raise ManifestDecodeError from e
 
     def __init__(self, mpd_xml):
         mpd = MPEGDASHParser.parse(
